@@ -18,6 +18,7 @@
 #include "sieveeditormenubar.h"
 #include "sieveeditortextmodewidget.h"
 #include "sieveeditortabwidget.h"
+
 #include <KStandardAction>
 #include <KLocalizedString>
 #include <QAction>
@@ -26,7 +27,6 @@ using namespace KSieveUi;
 
 SieveEditorMenuBar::SieveEditorMenuBar(QWidget *parent)
     : QMenuBar(parent)
-    , mTextModeWidget(nullptr)
 {
     initActions();
     initMenus();
@@ -90,10 +90,7 @@ void SieveEditorMenuBar::initActions()
     mPrintAction = KStandardAction::print(this, &SieveEditorMenuBar::print, this);
     mPrintPreviewAction = KStandardAction::printPreview(this, &SieveEditorMenuBar::printPreview, this);
 
-    mZoomResetAction = new QAction(i18nc("Reset the zoom", "Reset"), this);
-    mZoomResetAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_0));
-    connect(mZoomResetAction, &QAction::triggered, this, &SieveEditorMenuBar::zoomReset);
-
+    mZoomResetAction = KStandardAction::actualSize(this, &SieveEditorMenuBar::zoomReset, this);
     mWordWrapAction = new QAction(i18n("Wordwrap"), this);
     mWordWrapAction->setCheckable(true);
     connect(mWordWrapAction, &QAction::triggered, this, &SieveEditorMenuBar::wordWrap);
