@@ -1,4 +1,4 @@
-/* Copyright (C) 2011-2017 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2011-2018 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -16,45 +16,41 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include "sievesyntaxspellcheckinghighlighter.h"
 #include "sievetextedit.h"
 #include "editor/sievelinenumberarea.h"
 #include "editor/sieveeditorutil.h"
-#include "KPIMTextEdit/EditorUtil"
 #include "editor/sievetexteditorspellcheckdecorator.h"
-#include "kpimtextedit/plaintextsyntaxspellcheckinghighlighter.h"
-#include <KLocalizedString>
-#include <QAction>
-#include <QIcon>
 
-#include <QAbstractItemView>
-#include <QCompleter>
-#include <QStringListModel>
-#include <QKeyEvent>
-#include <QPainter>
-#include <QScrollBar>
-#include <QMenu>
-#include <QFontDatabase>
-
-#include <KPIMTextEdit/SyntaxHighlighterBase>
+#include <KPIMTextEdit/PlainTextSyntaxSpellCheckingHighlighter>
+#include <KPIMTextEdit/EditorUtil>
 #include <KPIMTextEdit/TextEditorCompleter>
 
+#include <KLocalizedString>
+#include <KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/Repository>
+#include <KSyntaxHighlighting/Theme>
+
+#include <QAction>
+#include <QIcon>
+#include <QAbstractItemView>
+#include <QKeyEvent>
+#include <QPainter>
+#include <QMenu>
+#include <QFontDatabase>
+#include <QCompleter>
 using namespace KSieveUi;
 
 class KSieveUi::SieveTextEditPrivate
 {
 public:
     SieveTextEditPrivate()
-        : m_sieveLineNumberArea(nullptr)
-        , mTextEditorCompleter(nullptr)
-        , mShowHelpMenu(true)
     {
     }
 
-    PimCommon::SieveSyntaxHighlighterRules mSieveHighliterRules;
-    SieveLineNumberArea *m_sieveLineNumberArea;
-    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter;
-    bool mShowHelpMenu;
+    SieveLineNumberArea *m_sieveLineNumberArea = nullptr;
+    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter = nullptr;
+    KSyntaxHighlighting::Repository mSyntaxRepo;
+    bool mShowHelpMenu = true;
 };
 
 SieveTextEdit::SieveTextEdit(QWidget *parent)
@@ -86,7 +82,7 @@ SieveTextEdit::~SieveTextEdit()
 
 void SieveTextEdit::updateHighLighter()
 {
-    KSieveUi::SieveSyntaxSpellCheckingHighlighter *hlighter = dynamic_cast<KSieveUi::SieveSyntaxSpellCheckingHighlighter *>(highlighter());
+    auto hlighter = dynamic_cast<KPIMTextEdit::PlainTextSyntaxSpellCheckingHighlighter *>(highlighter());
     if (hlighter) {
         hlighter->toggleSpellHighlighting(checkSpellingEnabled());
     }
@@ -99,10 +95,13 @@ void SieveTextEdit::clearDecorator()
 
 void SieveTextEdit::createHighlighter()
 {
-    KSieveUi::SieveSyntaxSpellCheckingHighlighter *highlighter = new KSieveUi::SieveSyntaxSpellCheckingHighlighter(this);
+    auto highlighter = new KPIMTextEdit::PlainTextSyntaxSpellCheckingHighlighter(this);
     highlighter->toggleSpellHighlighting(checkSpellingEnabled());
     highlighter->setCurrentLanguage(spellCheckingLanguage());
-    highlighter->setSyntaxHighlighterRules(d->mSieveHighliterRules.rules());
+    highlighter->setDefinition(d->mSyntaxRepo.definitionForName(QStringLiteral("Sieve")));
+    highlighter->setTheme((palette().color(QPalette::Base).lightness() < 128)
+                          ? d->mSyntaxRepo.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
+                          : d->mSyntaxRepo.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
     setHighlighter(highlighter);
 }
 
@@ -123,7 +122,7 @@ int SieveTextEdit::lineNumberAreaWidth() const
         ++digits;
     }
 
-    const int space = 3 + fontMetrics().width(QLatin1Char('9')) * digits;
+    const int space = 2 + fontMetrics().boundingRect(QLatin1Char('9')).width() * digits;
     return space;
 }
 
@@ -134,8 +133,8 @@ void SieveTextEdit::lineNumberAreaPaintEvent(QPaintEvent *event)
 
     QTextBlock block = firstVisibleBlock();
     int blockNumber = block.blockNumber();
-    int top = (int)blockBoundingGeometry(block).translated(contentOffset()).top();
-    int bottom = top + (int)blockBoundingRect(block).height();
+    int top = static_cast<int>(blockBoundingGeometry(block).translated(contentOffset()).top());
+    int bottom = top + static_cast<int>(blockBoundingRect(block).height());
     while (block.isValid() && top <= event->rect().bottom()) {
         if (block.isVisible() && bottom >= event->rect().top()) {
             const QString number = QString::number(blockNumber + 1);
@@ -146,7 +145,7 @@ void SieveTextEdit::lineNumberAreaPaintEvent(QPaintEvent *event)
 
         block = block.next();
         top = bottom;
-        bottom = top + (int)blockBoundingRect(block).height();
+        bottom = top + static_cast<int>(blockBoundingRect(block).height());
         ++blockNumber;
     }
 }
@@ -259,7 +258,7 @@ void SieveTextEdit::keyPressEvent(QKeyEvent *e)
     } else if (handleShortcut(e)) {
         return;
     }
-    QPlainTextEdit::keyPressEvent(e);
+    KPIMTextEdit::PlainTextEditor::keyPressEvent(e);
     if (e->key() == Qt::Key_F1 && !textCursor().hasSelection()) {
         const QString word = selectedWord();
         const KSieveUi::SieveEditorUtil::HelpVariableName type = KSieveUi::SieveEditorUtil::strToVariableName(word);
@@ -276,12 +275,6 @@ void SieveTextEdit::keyPressEvent(QKeyEvent *e)
 
 void SieveTextEdit::setSieveCapabilities(const QStringList &capabilities)
 {
-    d->mSieveHighliterRules.addCapabilities(capabilities);
-    KPIMTextEdit::PlainTextSyntaxSpellCheckingHighlighter *hlighter = dynamic_cast<KPIMTextEdit::PlainTextSyntaxSpellCheckingHighlighter *>(highlighter());
-    if (hlighter) {
-        hlighter->setSyntaxHighlighterRules(d->mSieveHighliterRules.rules());
-    }
-
     setCompleterList(completerList() + capabilities);
 }
 
