@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -29,19 +29,18 @@ public:
     CheckScriptJobPrivate()
         : mIsActive(false)
     {
-
     }
-    bool mIsActive;
+
+    QUrl mUrl;
     QString mOriginalScript;
     QString mCurrentScript;
-    QUrl mUrl;
+    bool mIsActive;
 };
 
 CheckScriptJob::CheckScriptJob(QObject *parent)
-    : QObject(parent),
-      d(new CheckScriptJobPrivate)
+    : QObject(parent)
+    , d(new CheckScriptJobPrivate)
 {
-
 }
 
 CheckScriptJob::~CheckScriptJob()
