@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,8 +23,7 @@
 #include "ksieveui_export.h"
 #include <QVector>
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveImapInstance;
 class KSIEVEUI_EXPORT SieveImapInstanceInterface
 {
