@@ -37,6 +37,7 @@
 #include <QCheckBox>
 #include <QGridLayout>
 #include <QLabel>
+#include <PimCommon/SpellCheckLineEdit>
 
 using KMime::Types::AddrSpecList;
 using KMime::Types::AddressList;
@@ -75,9 +76,9 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
 
     // Subject
     ++row;
-    mSubject = new QLineEdit(this);
+    mSubject = new PimCommon::SpellCheckLineEdit(this, QString());
     mSubject->setObjectName(QStringLiteral("mSubject"));
-    mSubject->setClearButtonEnabled(true);
+    //mSubject->setClearButtonEnabled(true);
     QLabel *subjectOfVacationLabel = new QLabel(i18n("&Subject of the vacation mail:"), this);
     subjectOfVacationLabel->setObjectName(QStringLiteral("subjectOfVacationLabel"));
     subjectOfVacationLabel->setBuddy(mSubject);
@@ -137,7 +138,6 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     timeLayout->addWidget(mEndTime);
     glay->addLayout(timeLayout, row, 1);
 
-
     // Hide the date edits by default - they must be enabled by caller when the
     // server supports this feature
     enableDates(false);
@@ -259,7 +259,6 @@ AddrSpecList VacationEditWidget::mailAliases(bool &ok) const
     const char *s = text.cbegin();
     AddrSpecList asl;
     if (parseAddressList(s, text.cend(), al)) {
-
         AddressList::const_iterator end(al.constEnd());
         for (AddressList::const_iterator it = al.constBegin(); it != end; ++it) {
             const MailboxList &mbl = (*it).mailboxList;
@@ -399,7 +398,7 @@ void VacationEditWidget::setSubject(const QString &subject)
 QString VacationEditWidget::subject() const
 {
     if (mSubject->isEnabled()) {
-        return mSubject->text();
+        return mSubject->toPlainText();
     } else {
         return QString();
     }
@@ -462,6 +461,10 @@ void VacationEditWidget::setDefault()
     setMailAction(VacationUtils::defaultMailAction(), QString());
     mStartTimeActive->setChecked(false);
     mEndTimeActive->setChecked(false);
+    mStartTime->setTime(QTime());
+    mEndTime->setTime(QTime());
+    mStartDate->setDate(QDate());
+    mEndDate->setDate(QDate());
     setDomainCheck(false);
     mDomainEdit->clear();
 }
