@@ -33,15 +33,9 @@
 #include <QVBoxLayout>
 #include <QLabel>
 
-#include "libksieve_debug.h"
-
 using namespace KSieveUi;
 VacationPageWidget::VacationPageWidget(QWidget *parent)
     : QWidget(parent)
-    , mVacationManager(nullptr)
-    , mPageScript(Script)
-    , mWasActive(false)
-    , mHasDateSupport(false)
 {
     QVBoxLayout *lay = new QVBoxLayout(this);
     lay->setMargin(0);
@@ -122,7 +116,7 @@ void VacationPageWidget::slotGetResult(const QString &serverName, const QStringL
     }
 
     mUrl = mUrl.adjusted(QUrl::RemoveFilename);
-    mUrl.setPath(mUrl.path() + scriptName);
+    mUrl.setPath(mUrl.path() + QLatin1Char('/') + scriptName);
 
     // Whether the server supports the "date" extension
     mHasDateSupport = mUrl.scheme() == QStringLiteral("sieve") && sieveCapabilities.contains(QLatin1String("date"));
