@@ -580,8 +580,9 @@ void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, c
     if (hasKep14EditorMode) {
         QUrl u = mUrls[parent];
         u = u.adjusted(QUrl::RemoveFilename);
-        u.setPath(u.path() + QStringLiteral("USER"));
-        ParseUserScriptJob *parseJob = new ParseUserScriptJob(u);
+        u.setPath(u.path() + QLatin1Char('/') + QStringLiteral("USER"));
+        ParseUserScriptJob *parseJob = new ParseUserScriptJob(u, this);
+        parseJob->setAutoDelete(true);
         parseJob->setProperty("parentItem", QVariant::fromValue<QTreeWidgetItem *>(parent));
         connect(parseJob, &ParseUserScriptJob::finished, this, &ManageSieveWidget::setActiveScripts);
         parseJob->start();
