@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,7 +24,6 @@
 using namespace KSieveUi;
 SieveTreeWidgetProgress::SieveTreeWidgetProgress(SieveTreeWidgetItem *item, QObject *parent)
     : QObject(parent)
-    , mProgressCount(0)
     , mItem(item)
 {
     KIconLoader loader;
@@ -66,7 +65,6 @@ class KSieveUi::SieveTreeWidgetItemPrivate
 {
 public:
     SieveTreeWidgetItemPrivate()
-        : mProgress(nullptr)
     {
     }
 
@@ -75,7 +73,7 @@ public:
         delete mProgress;
     }
 
-    SieveTreeWidgetProgress *mProgress;
+    SieveTreeWidgetProgress *mProgress = nullptr;
 };
 
 SieveTreeWidgetItem::SieveTreeWidgetItem(QTreeWidget *treeWidget, QTreeWidgetItem *item)
